==> syncope-2.1.10-source-release.zip: syncope-2.1.10/fit/core-reference/src/main/java/org/apache/syncope/fit/core/reference/SyslogRewriteAuditAppender.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.fit.core.reference;

import java.util.HashSet;
import java.util.Set;
import org.apache.logging.log4j.core.appender.SyslogAppender;
import org.apache.logging.log4j.core.layout.PatternLayout;
import org.apache.logging.log4j.core.net.Facility;
import org.apache.logging.log4j.core.net.Protocol;
import org.apache.syncope.common.lib.types.AuditElements;
import org.apache.syncope.common.lib.types.AuditLoggerName;
import org.apache.syncope.core.logic.ConnectorLogic;
import org.apache.syncope.core.logic.audit.DefaultRewriteAuditAppender;
import org.apache.syncope.core.logic.ResourceLogic;

public class SyslogRewriteAuditAppender extends DefaultRewriteAuditAppender {

    @Override
    public Set<AuditLoggerName> getEvents() {
        Set<AuditLoggerName> events = new HashSet<>();
        events.add(new AuditLoggerName.Builder().
                type(AuditElements.EventCategoryType.LOGIC).
                category(ResourceLogic.class.getSimpleName()).
                event("update").
                result(AuditElements.Result.SUCCESS).build());
        events.add(new AuditLoggerName.Builder().
                type(AuditElements.EventCategoryType.LOGIC).
                category(ConnectorLogic.class.getSimpleName()).
                event("update").
                result(AuditElements.Result.SUCCESS).build());
        events.add(new AuditLoggerName.Builder().
                type(AuditElements.EventCategoryType.LOGIC).
                category(ResourceLogic.class.getSimpleName()).
                event("delete").
                result(AuditElements.Result.SUCCESS).build());
        return events;
    }

    @Override
    protected void initTargetAppender() {
        targetAppender = SyslogAppender.newSyslogAppenderBuilder().
                setName(getTargetAppenderName()).
                withHost("localhost").
                withPort(514).
                withProtocol(Protocol.UDP).
                setLayout(PatternLayout.newBuilder().withPattern("%d{ISO8601} %-5level %logger - %msg%n").build()).
                setFacility(Facility.LOCAL1).
                build();
    }

    @Override
    public String getTargetAppenderName() {
        return "audit_for_" + domain + "_syslog";
    }
}

==> syncope-2.1.14-source-release.zip: syncope-2.1.14/fit/core-reference/src/main/java/org/apache/syncope/fit/core/reference/SyslogRewriteAuditAppender.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.fit.core.reference;

import java.util.HashSet;
import java.util.Set;
import org.apache.logging.log4j.core.appender.SyslogAppender;
import org.apache.logging.log4j.core.layout.PatternLayout;
import org.apache.logging.log4j.core.net.Facility;
import org.apache.logging.log4j.core.net.Protocol;
import org.apache.syncope.common.lib.types.AuditElements;
import org.apache.syncope.common.lib.types.AuditLoggerName;
import org.apache.syncope.core.logic.ConnectorLogic;
import org.apache.syncope.core.logic.audit.DefaultRewriteAuditAppender;
import org.apache.syncope.core.logic.ResourceLogic;

public class SyslogRewriteAuditAppender extends DefaultRewriteAuditAppender {

    @Override
    public Set<AuditLoggerName> getEvents() {
        Set<AuditLoggerName> events = new HashSet<>();
        events.add(new AuditLoggerName.Builder().
                type(AuditElements.EventCategoryType.LOGIC).
                category(ResourceLogic.class.getSimpleName()).
                event("update").
                result(AuditElements.Result.SUCCESS).build());
        events.add(new AuditLoggerName.Builder().
                type(AuditElements.EventCategoryType.LOGIC).
                category(ConnectorLogic.class.getSimpleName()).
                event("update").
                result(AuditElements.Result.SUCCESS).build());
        events.add(new AuditLoggerName.Builder().
                type(AuditElements.EventCategoryType.LOGIC).
                category(ResourceLogic.class.getSimpleName()).
                event("delete").
                result(AuditElements.Result.SUCCESS).build());
        return events;
    }

    @Override
    protected void initTargetAppender() {
        targetAppender = SyslogAppender.newSyslogAppenderBuilder().
                setName(getTargetAppenderName()).
                setHost("localhost").
                setPort(514).
                setProtocol(Protocol.UDP).
                setLayout(PatternLayout.newBuilder().withPattern("%d{ISO8601} %-5level %logger - %msg%n").build()).
                setFacility(Facility.LOCAL1).
                build();
    }

    @Override
    public String getTargetAppenderName() {
        return "audit_for_" + domain + "_syslog";
    }
}
